@@ -33,6 +33,9 @@ private:
 
     double generator_derivative2(const double &u);
 
+    // pdf
+    Eigen::VectorXd pdf(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u);
+
     // link between Kendall's tau and the par_bicop parameter
     double parameters_to_tau(const Eigen::MatrixXd &par);
 
