@@ -33,6 +33,9 @@ private:
 
     double generator_derivative2(const double &u);
 
+    // pdf
+    Eigen::VectorXd pdf(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u);
+
     // inverse hfunction
     Eigen::VectorXd hinv1(
         const Eigen::Matrix<double, Eigen::Dynamic, 2> &u
